@@ -85,11 +85,13 @@ typedef struct filter_instance {
 	 * Memory pool for use with persistent data.
 	 */
 	isc_mempool_t *datapool;
+	isc_mutex_t plock;
 
 	/*
 	 * Hash table associating a client object with its persistent data.
 	 */
 	isc_ht_t *ht;
+	isc_mutex_t hlock;
 
 	/*
 	 * Values configured when the module is loaded.
@@ -307,8 +309,8 @@ parse_parameters(filter_instance_t *inst, const char *parameters,
 
 	isc_buffer_constinit(&b, parameters, strlen(parameters));
 	isc_buffer_add(&b, strlen(parameters));
-	CHECK(cfg_parse_buffer4(parser, &b, cfg_file, cfg_line,
-				&cfg_type_parameters, 0, &param_obj));
+	CHECK(cfg_parse_buffer(parser, &b, cfg_file, cfg_line,
+			       &cfg_type_parameters, 0, &param_obj));
 
 	CHECK(check_syntax(param_obj, cfg, mctx, lctx, actx));
 
@@ -377,6 +379,7 @@ plugin_register(const char *parameters,
 	CHECK(isc_mempool_create(mctx, sizeof(filter_data_t),
 				 &inst->datapool));
 	CHECK(isc_ht_init(&inst->ht, mctx, 16));
+	isc_mutex_init(&inst->hlock);
 
 	/*
 	 * Fill the mempool with 1K filter_aaaa state objects at
@@ -390,6 +393,8 @@ plugin_register(const char *parameters,
 	 */
 	isc_mempool_setfillcount(inst->datapool, 1024);
 	isc_mempool_setfreemax(inst->datapool, UINT_MAX);
+	isc_mutex_init(&inst->plock);
+	isc_mempool_associatelock(inst->datapool, &inst->plock);
 
 	/*
 	 * Set hook points in the view's hooktable.
@@ -420,8 +425,8 @@ plugin_check(const char *parameters,
 
 	isc_buffer_constinit(&b, parameters, strlen(parameters));
 	isc_buffer_add(&b, strlen(parameters));
-	CHECK(cfg_parse_buffer4(parser, &b, cfg_file, cfg_line,
-				&cfg_type_parameters, 0, &param_obj));
+	CHECK(cfg_parse_buffer(parser, &b, cfg_file, cfg_line,
+			       &cfg_type_parameters, 0, &param_obj));
 
 	CHECK(check_syntax(param_obj, cfg, mctx, lctx, actx));
 
@@ -445,9 +450,11 @@ plugin_destroy(void **instp) {
 
 	if (inst->ht != NULL) {
 		isc_ht_destroy(&inst->ht);
+		isc_mutex_destroy(&inst->hlock);
 	}
 	if (inst->datapool != NULL) {
 		isc_mempool_destroy(&inst->datapool);
+		isc_mutex_destroy(&inst->plock);
 	}
 	if (inst->aaaa_acl != NULL) {
 		dns_acl_detach(&inst->aaaa_acl);
@@ -517,8 +524,10 @@ client_state_get(const query_ctx_t *qctx, filter_instance_t *inst) {
 	filter_data_t *client_state = NULL;
 	isc_result_t result;
 
+	LOCK(&inst->hlock);
 	result = isc_ht_find(inst->ht, (const unsigned char *)&qctx->client,
 			     sizeof(qctx->client), (void **)&client_state);
+	UNLOCK(&inst->hlock);
 
 	return (result == ISC_R_SUCCESS ? client_state : NULL);
 }
@@ -536,8 +545,10 @@ client_state_create(const query_ctx_t *qctx, filter_instance_t *inst) {
 	client_state->mode = NONE;
 	client_state->flags = 0;
 
+	LOCK(&inst->hlock);
 	result = isc_ht_add(inst->ht, (const unsigned char *)&qctx->client,
 			    sizeof(qctx->client), client_state);
+	UNLOCK(&inst->hlock);
 	RUNTIME_CHECK(result == ISC_R_SUCCESS);
 }
 
@@ -550,8 +561,10 @@ client_state_destroy(const query_ctx_t *qctx, filter_instance_t *inst) {
 		return;
 	}
 
+	LOCK(&inst->hlock);
 	result = isc_ht_delete(inst->ht, (const unsigned char *)&qctx->client,
 			       sizeof(qctx->client));
+	UNLOCK(&inst->hlock);
 	RUNTIME_CHECK(result == ISC_R_SUCCESS);
 
 	isc_mempool_put(inst->datapool, client_state);
@@ -592,8 +605,9 @@ process_name(query_ctx_t *qctx, filter_aaaa_t mode, const dns_name_t *name,
 		CHECK(dns_message_findtype(name, dns_rdatatype_a, 0, NULL));
 	}
 
-	dns_message_findtype(name, type, 0, &rdataset);
-	dns_message_findtype(name, dns_rdatatype_rrsig, type, &sigrdataset);
+	(void)dns_message_findtype(name, type, 0, &rdataset);
+	(void)dns_message_findtype(name, dns_rdatatype_rrsig, type,
+				   &sigrdataset);
 
 	if (rdataset != NULL &&
 	    (sigrdataset == NULL || !WANTDNSSEC(qctx->client) ||
