@@ -1,12 +1,13 @@
 #!/bin/sh
 #
-# Copyright (C) 2012, 2016  Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
-
-# $Id$
+#
+# See the COPYRIGHT file distributed with this work for additional
+# information regarding copyright ownership.
 
 SYSTEMTESTTOP=..
 . $SYSTEMTESTTOP/conf.sh
@@ -15,28 +16,28 @@ status=0
 
 rm -f dig.out.*
 
-DIGOPTS="+tcp +noadd +nosea +nostat +nocmd +dnssec -p 5300"
+DIGOPTS="+tcp +noadd +nosea +nostat +nocmd +dnssec -p ${PORT}"
 
 # Check the good. domain
 
-echo "I:checking that validation with enabled digest types works"
+echo_i "checking that validation with enabled digest types works"
 ret=0
 $DIG $DIGOPTS a.good. @10.53.0.3 a > dig.out.good || ret=1
 grep "status: NOERROR" dig.out.good > /dev/null || ret=1
 grep "flags:[^;]* ad[ ;]" dig.out.good > /dev/null || ret=1
-if [ $ret != 0 ]; then echo "I:failed"; fi
+if [ $ret != 0 ]; then echo_i "failed"; fi
 status=`expr $status + $ret`
 
 # Check the bad. domain
 
-echo "I:checking that validation with no supported digest types and must-be-secure results in SERVFAIL"
+echo_i "checking that validation with no supported digest types and must-be-secure results in SERVFAIL"
 ret=0
 $DIG $DIGOPTS a.bad. @10.53.0.3 a > dig.out.bad || ret=1
 grep "SERVFAIL" dig.out.bad > /dev/null || ret=1
-if [ $ret != 0 ]; then echo "I:failed"; fi
+if [ $ret != 0 ]; then echo_i "failed"; fi
 status=`expr $status + $ret`
 
-echo "I:checking that validation with no supported digest algorithms results in insecure"
+echo_i "checking that validation with no supported digest algorithms results in insecure"
 ret=0
 $DIG $DIGOPTS bad. @10.53.0.4 ds > dig.out.ds || ret=1
 grep "NOERROR" dig.out.ds > /dev/null || ret=1
@@ -44,8 +45,8 @@ grep "flags:[^;]* ad[ ;]" dig.out.ds > /dev/null || ret=1
 $DIG $DIGOPTS a.bad. @10.53.0.4 a > dig.out.insecure || ret=1
 grep "NOERROR" dig.out.insecure > /dev/null || ret=1
 grep "flags:[^;]* ad[ ;]" dig.out.insecure > /dev/null && ret=1
-if [ $ret != 0 ]; then echo "I:failed"; fi
+if [ $ret != 0 ]; then echo_i "failed"; fi
 status=`expr $status + $ret`
-echo "I:exit status: $status"
+echo_i "exit status: $status"
 
 [ $status -eq 0 ] || exit 1
