@@ -14,7 +14,7 @@ rm -f ns2/example*.db
 rm -f dig.out.* rndc.out.*
 rm -f data2/*dat
 [ -d data2 ] && rmdir data2
-rm -f ns?/named.run
+rm -f ns?/named.run ns?/named.run.*
 rm -f ns?/named.memstats
 rm -f ns*/named.lock
 rm -f ns*/managed-keys.bind* ns*/*.mkeys*
