@@ -16,11 +16,13 @@
  ***** Module Info
  *****/
 
-/*! \file dns/acl.h
+/*! \file dns/geoip.h
  * \brief
- * Address match list handling.
+ * GeoIP/GeoIP2 data types and function prototypes.
  */
 
+#if defined(HAVE_GEOIP) || defined(HAVE_GEOIP2)
+
 /***
  *** Imports
  ***/
@@ -36,12 +38,6 @@
 #include <dns/types.h>
 #include <dns/iptable.h>
 
-#ifdef HAVE_GEOIP
-#include <GeoIP.h>
-#else
-typedef void GeoIP;
-#endif
-
 /***
  *** Types
  ***/
@@ -50,11 +46,15 @@ typedef enum {
 	dns_geoip_countrycode,
 	dns_geoip_countrycode3,
 	dns_geoip_countryname,
+	dns_geoip_continentcode,
+	dns_geoip_continent,
 	dns_geoip_region,
 	dns_geoip_regionname,
 	dns_geoip_country_code,
 	dns_geoip_country_code3,
 	dns_geoip_country_name,
+	dns_geoip_country_continentcode,
+	dns_geoip_country_continent,
 	dns_geoip_region_countrycode,
 	dns_geoip_region_code,
 	dns_geoip_region_name,
@@ -68,6 +68,7 @@ typedef enum {
 	dns_geoip_city_metrocode,
 	dns_geoip_city_areacode,
 	dns_geoip_city_continentcode,
+	dns_geoip_city_continent,
 	dns_geoip_city_timezonecode,
 	dns_geoip_isp_name,
 	dns_geoip_org_name,
@@ -78,25 +79,33 @@ typedef enum {
 
 typedef struct dns_geoip_elem {
 	dns_geoip_subtype_t subtype;
-	GeoIP *db;
+	void *db;
 	union {
 		char as_string[256];
 		int as_int;
 	};
 } dns_geoip_elem_t;
 
-typedef struct dns_geoip_databases {
-	GeoIP *country_v4;			/* DB 1        */
-	GeoIP *city_v4;				/* DB 2 or 6   */
-	GeoIP *region;				/* DB 3 or 7   */
-	GeoIP *isp;				/* DB 4        */
-	GeoIP *org;				/* DB 5        */
-	GeoIP *as;				/* DB 9        */
-	GeoIP *netspeed;			/* DB 10       */
-	GeoIP *domain;				/* DB 11       */
-	GeoIP *country_v6;			/* DB 12       */
-	GeoIP *city_v6;				/* DB 30 or 31 */
-} dns_geoip_databases_t;
+struct dns_geoip_databases {
+#ifdef HAVE_GEOIP2
+	void *country;		/* GeoIP2-Country or GeoLite2-Country */
+	void *city;		/* GeoIP2-CIty or GeoLite2-City */
+	void *domain;		/* GeoIP2-Domain */
+	void *isp;		/* GeoIP2-ISP */
+	void *as;		/* GeoIP2-ASN or GeoLite2-ASN */
+#else /* HAVE_GEOIP */
+	void *country_v4;	/* GeoIP DB 1 */
+	void *city_v4;		/* GeoIP DB 2 or 6 */
+	void *region;		/* GeoIP DB 3 or 7 */
+	void *isp;		/* GeoIP DB 4 */
+	void *org;		/* GeoIP DB 5 */
+	void *as;		/* GeoIP DB 9 */
+	void *netspeed;		/* GeoIP DB 10 */
+	void *domain;		/* GeoIP DB 11 */
+	void *country_v6;	/* GeoIP DB 12 */
+	void *city_v6;		/* GeoIP DB 30 or 31 */
+#endif /* HAVE_GEOIP */
+};
 
 /***
  *** Functions
@@ -105,7 +114,7 @@ typedef struct dns_geoip_databases {
 ISC_LANG_BEGINDECLS
 
 bool
-dns_geoip_match(const isc_netaddr_t *reqaddr, uint8_t *scope,
+dns_geoip_match(const isc_netaddr_t *reqaddr,
 		const dns_geoip_databases_t *geoip,
 		const dns_geoip_elem_t *elt);
 
@@ -113,4 +122,7 @@ void
 dns_geoip_shutdown(void);
 
 ISC_LANG_ENDDECLS
+
+#endif /* HAVE_GEOIP | HAVE_GEOIP2 */
+
 #endif /* DNS_GEOIP_H */
