@@ -1047,9 +1047,7 @@ chain_name(dns_rbtnodechain_t *chain, dns_name_t *name,
 
 	if (include_chain_end && chain->end != NULL) {
 		NODENAME(chain->end, &nodename);
-		result = dns_name_copy(&nodename, name, NULL);
-		if (result != ISC_R_SUCCESS)
-			return (result);
+		dns_name_copynf(&nodename, name);
 	} else
 		dns_name_reset(name);
 
@@ -2690,6 +2688,7 @@ deletefromlevel(dns_rbtnode_t *item, dns_rbtnode_t **rootp) {
 	 * Fix color violations.
 	 */
 	if (IS_BLACK(item)) {
+		/* cppcheck-suppress nullPointerRedundantCheck symbolName=item */
 		parent = PARENT(item);
 
 		while (child != *rootp && IS_BLACK(child)) {
@@ -2707,6 +2706,7 @@ deletefromlevel(dns_rbtnode_t *item, dns_rbtnode_t **rootp) {
 
 				INSIST(sibling != NULL);
 
+				/* cppcheck-suppress nullPointerRedundantCheck symbolName=sibling */
 				if (IS_BLACK(LEFT(sibling)) &&
 				    IS_BLACK(RIGHT(sibling))) {
 					MAKE_RED(sibling);
@@ -2746,6 +2746,7 @@ deletefromlevel(dns_rbtnode_t *item, dns_rbtnode_t **rootp) {
 
 				INSIST(sibling != NULL);
 
+				/* cppcheck-suppress nullPointerRedundantCheck symbolName=sibling */
 				if (IS_BLACK(LEFT(sibling)) &&
 				    IS_BLACK(RIGHT(sibling))) {
 					MAKE_RED(sibling);
@@ -2877,6 +2878,7 @@ check_properties_helper(dns_rbtnode_t *node) {
 			return (false);
 	}
 
+	/* cppcheck-suppress nullPointerRedundantCheck symbolName=node */
 	if ((DOWN(node) != NULL) && (!IS_ROOT(DOWN(node))))
 		return (false);
 
@@ -2914,12 +2916,15 @@ check_black_distance_helper(dns_rbtnode_t *node, size_t *distance) {
 		return (true);
 	}
 
+	/* cppcheck-suppress nullPointerRedundantCheck symbolName=node */
 	if (!check_black_distance_helper(LEFT(node), &dl))
 		return (false);
 
+	/* cppcheck-suppress nullPointerRedundantCheck symbolName=node */
 	if (!check_black_distance_helper(RIGHT(node), &dr))
 		return (false);
 
+	/* cppcheck-suppress nullPointerRedundantCheck symbolName=node */
 	if (!check_black_distance_helper(DOWN(node), &dd))
 		return (false);
 
@@ -3204,10 +3209,11 @@ dns_rbtnodechain_current(dns_rbtnodechain_t *chain, dns_name_t *name,
 	}
 
 	if (origin != NULL) {
-		if (chain->level_count > 0)
+		if (chain->level_count > 0) {
 			result = chain_name(chain, origin, false);
-		else
-			result = dns_name_copy(dns_rootname, origin, NULL);
+		} else {
+			dns_name_copynf(dns_rootname, origin);
+		}
 	}
 
 	return (result);
