@@ -1521,7 +1521,7 @@ check_apex_rrsets(vctx_t *vctx) {
  * The variables to update are chosen based on 'is_ksk', which is true when
  * 'dnskey' is a KSK and false otherwise.
  */
-static isc_result_t
+static void
 check_dnskey_sigs(vctx_t *vctx, const dns_rdata_dnskey_t *dnskey,
 		  dns_rdata_t *rdata, bool is_ksk)
 {
@@ -1535,25 +1535,26 @@ check_dnskey_sigs(vctx_t *vctx, const dns_rdata_dnskey_t *dnskey,
 	standby_keys = (is_ksk ? vctx->standby_ksk : vctx->standby_zsk);
 	goodkey = (is_ksk ? &vctx->goodksk : &vctx->goodzsk);
 
-	if (dns_dnssec_selfsigns(rdata, vctx->origin, &vctx->keyset,
+	if (!dns_dnssec_selfsigns(rdata, vctx->origin, &vctx->keyset,
 				 &vctx->keysigs, false, vctx->mctx))
 	{
-		if (active_keys[dnskey->algorithm] != 255) {
-			active_keys[dnskey->algorithm]++;
+		if (!is_ksk &&
+		    dns_dnssec_signs(rdata, vctx->origin, &vctx->soaset,
+				     &vctx->soasigs, false, vctx->mctx))
+		{
+			if (active_keys[dnskey->algorithm] != 255) {
+				active_keys[dnskey->algorithm]++;
+			}
+		} else {
+			if (standby_keys[dnskey->algorithm] != 255) {
+				standby_keys[dnskey->algorithm]++;
+			}
 		}
-	} else if (!is_ksk &&
-		   dns_dnssec_signs(rdata, vctx->origin, &vctx->soaset,
-				    &vctx->soasigs, false, vctx->mctx))
-	{
-		if (active_keys[dnskey->algorithm] != 255) {
-			active_keys[dnskey->algorithm]++;
-		}
-		return (ISC_R_SUCCESS);
-	} else {
-		if (standby_keys[dnskey->algorithm] != 255) {
-			standby_keys[dnskey->algorithm]++;
-		}
-		return (ISC_R_SUCCESS);
+		return;
+	}
+
+	if (active_keys[dnskey->algorithm] != 255) {
+		active_keys[dnskey->algorithm]++;
 	}
 
 	/*
@@ -1562,7 +1563,7 @@ check_dnskey_sigs(vctx_t *vctx, const dns_rdata_dnskey_t *dnskey,
 	 */
 	if (vctx->secroots == NULL) {
 		*goodkey = true;
-		return (ISC_R_SUCCESS);
+		return;
 	}
 
 	/*
@@ -1571,7 +1572,7 @@ check_dnskey_sigs(vctx_t *vctx, const dns_rdata_dnskey_t *dnskey,
 	result = dns_dnssec_keyfromrdata(vctx->origin, rdata, vctx->mctx,
 					 &key);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		goto cleanup;
 	}
 
 	result = dns_keytable_findkeynode(vctx->secroots, vctx->origin,
@@ -1582,10 +1583,6 @@ check_dnskey_sigs(vctx_t *vctx, const dns_rdata_dnskey_t *dnskey,
 	 * No such trust anchor.
 	 */
 	if (result != ISC_R_SUCCESS) {
-		if (result == DNS_R_PARTIALMATCH || result == ISC_R_NOTFOUND) {
-			result = ISC_R_SUCCESS;
-		}
-
 		goto cleanup;
 	}
 
@@ -1614,7 +1611,6 @@ check_dnskey_sigs(vctx_t *vctx, const dns_rdata_dnskey_t *dnskey,
 	if (key != NULL) {
 		dst_key_free(&key);
 	}
-	return (ISC_R_SUCCESS);
 }
 
 /*%
@@ -1805,11 +1801,11 @@ verify_nodes(vctx_t *vctx, isc_result_t *vresult) {
 		}
 		if (is_delegation(vctx, name, node, NULL)) {
 			zonecut = dns_fixedname_name(&fzonecut);
-			dns_name_copy(name, zonecut, NULL);
+			dns_name_copynf(name, zonecut);
 			isdelegation = true;
 		} else if (has_dname(vctx, node)) {
 			zonecut = dns_fixedname_name(&fzonecut);
-			dns_name_copy(name, zonecut, NULL);
+			dns_name_copynf(name, zonecut);
 		}
 		nextnode = NULL;
 		result = dns_dbiterator_next(dbiter);
@@ -1890,7 +1886,7 @@ verify_nodes(vctx_t *vctx, isc_result_t *vresult) {
 		} else {
 			prevname = dns_fixedname_name(&fprevname);
 		}
-		dns_name_copy(name, prevname, NULL);
+		dns_name_copynf(name, prevname);
 		if (*vresult == ISC_R_SUCCESS) {
 			*vresult = tvresult;
 		}
