@@ -16,8 +16,8 @@
  * Performance
  */
 #ifdef HAVE_BUILTIN_EXPECT
-#define ISC_LIKELY(x)            __builtin_expect((x), 1)
-#define ISC_UNLIKELY(x)          __builtin_expect((x), 0)
+#define ISC_LIKELY(x)            __builtin_expect(!!(x), 1)
+#define ISC_UNLIKELY(x)          __builtin_expect(!!(x), 0)
 #else
 #define ISC_LIKELY(x)            (x)
 #define ISC_UNLIKELY(x)          (x)
