@@ -1,24 +1,21 @@
 /*
- * Copyright (C) 2004, 2005  Internet Systems Consortium, Inc. ("ISC")
- * Copyright (C) 1999-2001, 2003  Internet Software Consortium.
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
- * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
- * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
- * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THIS SOFTWARE.
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id: lfsr.c,v 1.11.2.5 2005/10/14 02:13:04 marka Exp $ */
+
+/*! \file */
 
 #include <config.h>
 
+#include <stddef.h>
+#include <inttypes.h>
 #include <stdlib.h>
 
 #include <isc/assertions.h>
@@ -28,8 +25,8 @@
 #define VALID_LFSR(x)	(x != NULL)
 
 void
-isc_lfsr_init(isc_lfsr_t *lfsr, isc_uint32_t state, unsigned int bits,
-	      isc_uint32_t tap, unsigned int count,
+isc_lfsr_init(isc_lfsr_t *lfsr, uint32_t state, unsigned int bits,
+	      uint32_t tap, unsigned int count,
 	      isc_lfsrreseed_t reseed, void *arg)
 {
 	REQUIRE(VALID_LFSR(lfsr));
@@ -49,10 +46,10 @@ isc_lfsr_init(isc_lfsr_t *lfsr, isc_uint32_t state, unsigned int bits,
 		lfsr->state = 0xffffffffU >> (32 - lfsr->bits);
 }
 
-/*
+/*!
  * Return the next state of the lfsr.
  */
-static inline isc_uint32_t
+static inline uint32_t
 lfsr_generate(isc_lfsr_t *lfsr)
 {
 
@@ -95,7 +92,7 @@ isc_lfsr_generate(isc_lfsr_t *lfsr, void *data, unsigned int count)
 
 	while (byte--) {
 		*p = 0;
-		for (bit = 0 ; bit < 7 ; bit++) {
+		for (bit = 0; bit < 7; bit++) {
 			*p |= lfsr_generate(lfsr);
 			*p <<= 1;
 		}
@@ -111,7 +108,7 @@ isc_lfsr_generate(isc_lfsr_t *lfsr, void *data, unsigned int count)
 	}
 }
 
-static inline isc_uint32_t
+static inline uint32_t
 lfsr_skipgenerate(isc_lfsr_t *lfsr, unsigned int skip)
 {
 	while (skip--)
@@ -138,11 +135,11 @@ isc_lfsr_skip(isc_lfsr_t *lfsr, unsigned int skip)
  * Skip states in lfsr1 and lfsr2 using the other's current state.
  * Return the final state of lfsr1 ^ lfsr2.
  */
-isc_uint32_t
+uint32_t
 isc_lfsr_generate32(isc_lfsr_t *lfsr1, isc_lfsr_t *lfsr2)
 {
-	isc_uint32_t state1, state2;
-	isc_uint32_t skip1, skip2;
+	uint32_t state1, state2;
+	uint32_t skip1, skip2;
 
 	REQUIRE(VALID_LFSR(lfsr1));
 	REQUIRE(VALID_LFSR(lfsr2));
