@@ -27,6 +27,7 @@
 #include <isc/log.h>
 #include <isc/magic.h>
 #include <isc/mem.h>
+#include <isc/platform.h>
 #include <isc/print.h>
 #include <isc/stat.h>
 #include <isc/stdio.h>
@@ -45,10 +46,6 @@
  */
 #define LOG_BUFFER_SIZE	(8 * 1024)
 
-#ifndef PATH_MAX
-#define PATH_MAX 1024	/* WIN32 and others don't define this. */
-#endif
-
 /*!
  * This is the structure that holds each named channel.  A simple linked
  * list chains all of the channels together, so an individual channel is
