@@ -243,7 +243,7 @@ cfg_printx(const cfg_obj_t *obj, unsigned int flags,
 isc_result_t
 cfg_create_tuple(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	isc_result_t result;
-	const cfg_tuplefielddef_t *fields = type->of;
+	const cfg_tuplefielddef_t *fields;
 	const cfg_tuplefielddef_t *f;
 	cfg_obj_t *obj = NULL;
 	unsigned int nfields = 0;
@@ -253,6 +253,8 @@ cfg_create_tuple(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	REQUIRE(type != NULL);
 	REQUIRE(ret != NULL && *ret == NULL);
 
+	fields = type->of;
+
 	for (f = fields; f->name != NULL; f++)
 		nfields++;
 
@@ -278,7 +280,7 @@ isc_result_t
 cfg_parse_tuple(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 {
 	isc_result_t result;
-	const cfg_tuplefielddef_t *fields = type->of;
+	const cfg_tuplefielddef_t *fields;
 	const cfg_tuplefielddef_t *f;
 	cfg_obj_t *obj = NULL;
 	unsigned int i;
@@ -287,6 +289,8 @@ cfg_parse_tuple(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 	REQUIRE(type != NULL);
 	REQUIRE(ret != NULL && *ret == NULL);
 
+	fields = type->of;
+
 	CHECK(cfg_create_tuple(pctx, type, &obj));
 	for (f = fields, i = 0; f->name != NULL; f++, i++)
 		CHECK(cfg_parse_obj(pctx, f->type, &obj->value.tuple[i]));
@@ -1795,13 +1799,15 @@ cfg_parse_spacelist(cfg_parser_t *pctx, const cfg_type_t *listtype,
 		    cfg_obj_t **ret)
 {
 	cfg_obj_t *listobj = NULL;
-	const cfg_type_t *listof = listtype->of;
+	const cfg_type_t *listof;
 	isc_result_t result;
 
 	REQUIRE(pctx != NULL);
 	REQUIRE(listtype != NULL);
 	REQUIRE(ret != NULL && *ret == NULL);
 
+	listof = listtype->of;
+
 	CHECK(cfg_create_list(pctx, listtype, &listobj));
 
 	for (;;) {
@@ -1905,7 +1911,7 @@ cfg_listelt_value(const cfg_listelt_t *elt) {
 isc_result_t
 cfg_parse_mapbody(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 {
-	const cfg_clausedef_t * const *clausesets = type->of;
+	const cfg_clausedef_t * const *clausesets;
 	isc_result_t result;
 	const cfg_clausedef_t * const *clauseset;
 	const cfg_clausedef_t *clause;
@@ -1920,6 +1926,8 @@ cfg_parse_mapbody(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 	REQUIRE(type != NULL);
 	REQUIRE(ret != NULL && *ret == NULL);
 
+	clausesets = type->of;
+
 	CHECK(create_map(pctx, type, &obj));
 
 	obj->value.map.clausesets = clausesets;
@@ -2596,7 +2604,7 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 				strlcat(buf, ".0", sizeof(buf));
 				if (inet_pton(AF_INET, buf, &in4a) == 1) {
 					isc_netaddr_fromin(na, &in4a);
-					return (ISC_R_SUCCESS);
+					return (ISC_R_IPV4PREFIX);
 				}
 			}
 		}
@@ -2672,7 +2680,7 @@ cfg_lookingat_netaddr(cfg_parser_t *pctx, unsigned int flags) {
 	REQUIRE(pctx != NULL);
 
 	result = token_addr(pctx, flags, &na_dummy);
-	return (result == ISC_R_SUCCESS);
+	return (result == ISC_R_SUCCESS || result == ISC_R_IPV4PREFIX);
 }
 
 isc_result_t
@@ -2836,14 +2844,18 @@ cfg_parse_netprefix(cfg_parser_t *pctx, const cfg_type_t *type,
 	isc_result_t result;
 	isc_netaddr_t netaddr;
 	unsigned int addrlen = 0, prefixlen;
+	bool expectprefix;
 
 	REQUIRE(pctx != NULL);
 	REQUIRE(ret != NULL && *ret == NULL);
 
 	UNUSED(type);
 
-	CHECK(cfg_parse_rawaddr(pctx, CFG_ADDR_V4OK | CFG_ADDR_V4PREFIXOK |
-				CFG_ADDR_V6OK, &netaddr));
+	result = cfg_parse_rawaddr(pctx, CFG_ADDR_V4OK | CFG_ADDR_V4PREFIXOK |
+				   CFG_ADDR_V6OK, &netaddr);
+	if (result != ISC_R_SUCCESS && result != ISC_R_IPV4PREFIX) {
+		CHECK(result);
+	}
 	switch (netaddr.family) {
 	case AF_INET:
 		addrlen = 32;
@@ -2855,6 +2867,7 @@ cfg_parse_netprefix(cfg_parser_t *pctx, const cfg_type_t *type,
 		INSIST(0);
 		ISC_UNREACHABLE();
 	}
+	expectprefix = (result == ISC_R_IPV4PREFIX);
 	CHECK(cfg_peektoken(pctx, 0));
 	if (pctx->token.type == isc_tokentype_special &&
 	    pctx->token.value.as_char == '/') {
@@ -2862,16 +2875,30 @@ cfg_parse_netprefix(cfg_parser_t *pctx, const cfg_type_t *type,
 		CHECK(cfg_gettoken(pctx, ISC_LEXOPT_NUMBER));
 		if (pctx->token.type != isc_tokentype_number) {
 			cfg_parser_error(pctx, CFG_LOG_NEAR,
-				     "expected prefix length");
+					 "expected prefix length");
 			return (ISC_R_UNEXPECTEDTOKEN);
 		}
 		prefixlen = pctx->token.value.as_ulong;
 		if (prefixlen > addrlen) {
 			cfg_parser_error(pctx, CFG_LOG_NOPREP,
-				     "invalid prefix length");
+					 "invalid prefix length");
 			return (ISC_R_RANGE);
 		}
+		result = isc_netaddr_prefixok(&netaddr, prefixlen);
+		if (result != ISC_R_SUCCESS) {
+			char buf[ISC_NETADDR_FORMATSIZE + 1];
+			isc_netaddr_format(&netaddr, buf, sizeof(buf));
+			cfg_parser_error(pctx, CFG_LOG_NOPREP,
+					 "'%s/%u': address/prefix length "
+					 "mismatch", buf, prefixlen);
+			return (ISC_R_FAILURE);
+		}
 	} else {
+		if (expectprefix) {
+			cfg_parser_error(pctx, CFG_LOG_NEAR,
+					 "incomplete IPv4 address or prefix");
+			return (ISC_R_FAILURE);
+		}
 		prefixlen = addrlen;
 	}
 	CHECK(cfg_create_obj(pctx, &cfg_type_netprefix, &obj));
@@ -3019,12 +3046,14 @@ cfg_print_sockaddr(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 
 void
 cfg_doc_sockaddr(cfg_printer_t *pctx, const cfg_type_t *type) {
-	const unsigned int *flagp = type->of;
+	const unsigned int *flagp;
 	int n = 0;
 
 	REQUIRE(pctx != NULL);
 	REQUIRE(type != NULL);
 
+	flagp = type->of;
+
 	cfg_print_cstr(pctx, "( ");
 	if ((*flagp & CFG_ADDR_V4OK) != 0) {
 		cfg_print_cstr(pctx, "<ipv4_address>");
